@@ -21,11 +21,12 @@ pub struct Logger {
 
 impl Logger {
     /// Creates a new `Logger` object.
+    #[must_use]
     pub fn new(buff_size:      usize,
                log_to_console: bool,
                log_to_file:    bool,
                file_path:      Option<String>)
-    -> Logger {
+               -> Logger {
                 Logger { buff_size,
                          buffer:     String::new(),
                          buff_count: 0,
@@ -34,6 +35,7 @@ impl Logger {
                          file_path }
     }
     /// Creates a new `Logger` object with default values.
+    #[must_use]
     pub fn new_default() -> Logger {
         Logger { buff_size:      10,
                  buff_count:     0,
@@ -52,18 +54,19 @@ impl Logger {
     /// let _ = l.log(None, "Test-Log.");
     /// let _ = l.log(None, "Test-Log.");
     /// let _ = l.log(None, "Test-Log.");
+    /// let _ = l.log(Some(vec!["Warning"]), "This is a warning.");
     /// ```
-    /// As you can see, we initialise a new Logger `l` with the buffer size 3. This means that only after 3x logging, the logger writes to the file.
-    /// Instead of `None`, you can also add things like `some(vec!["warning", "low urgency"])`. Then, one line of the output will look like this:
-    /// `[2021-12-13T18:08:06Z][warning][low urgency] Test-Log.`
+    /// As you can see, we initialise a new Logger `l` with the buffer size 3. This means that only after 3x logging, the logger writes to the file and to the console.
+    #[must_use]
     pub fn log(&mut self, prefixes: Option<Vec<&str>>, msg: &str) -> Result<bool, String> {
         self.buff_count.inc();
-        let mut out: String = format!("[{}]", Utc::now().to_rfc3339_opts(SecondsFormat::Secs, true));
+        let mut out: String = format!("[{}]", Utc::now()
+                                                   .to_rfc3339_opts(SecondsFormat::Secs,
+                                                                    true));
         match prefixes {
             Some(v) => {
-                for s in v {
-                    out.push_str(&format!("[{}]", s));
-                }
+                for s in v
+                { out.push_str(&format!("[{}]", s)); }
             }
             None => { }
         }
@@ -72,9 +75,9 @@ impl Logger {
         out.push('\n');
         self.buffer += &out;
 
-        if self.buff_count == self.buff_size {
-            return self.backend_log();
-        }
+        if self.buff_count == self.buff_size
+        { return self.backend_log(); }
+
         Ok(true)
     }
     /// Resets `buffer` and `buff_counter`.
@@ -91,18 +94,17 @@ impl Logger {
                                     .open(&self.file_path.as_ref().unwrap());
             let mut file = match file {
                 Ok(f)  => f,
-                Err(e) => { return Err(format!("Problem opening or creating file: {:?}", e)); },
+                Err(e) => { return Err(format!("Problem opening or creating file: {:?}", e)); }
             };
             match write!(file, "{}", self.buffer) {
-                Ok(_)  => { },
-                Err(e) => { return Err(format!("Problem writing to file: {:?}", e)); },
+                Ok(_)  => { }
+                Err(e) => { return Err(format!("Problem writing to file: {:?}", e)); }
             }
         }
 
         if self.log_to_console {
-            { print!("{}", self.buffer);
-                     std::io::stdout().flush().unwrap();
-            }
+            print!("{}", self.buffer);
+            std::io::stdout().flush().unwrap();
         }
         self.reset_buffs();
         Ok(true)
