@@ -17,6 +17,7 @@ impl MathVector {
     ///
     /// # Returns
     /// A new MathVector.
+    #[must_use]
     pub fn new(values: &[f64]) -> MathVector {        
         MathVector { values: values.to_owned(),
                      length: None }
@@ -28,15 +29,17 @@ impl MathVector {
     ///
     /// # Returns
     /// A new MathVector with length 0.
+    #[must_use]
     pub fn new_with_dimension(dim: usize) -> MathVector {
 
-        MathVector { values: vec![0f64; dim],
+        MathVector { values: vec![0.0; dim],
                      length: None }
     }
     /// Gets the dimension in which a `MathVector` lives.
     ///
     /// # Returns
     /// A `usize`.
+    #[must_use]
     pub fn dimension(&self) -> usize {
         self.values.len()
     }
@@ -44,9 +47,10 @@ impl MathVector {
     ///
     /// # Returns
     /// A `f64`.
+    #[must_use]
     pub fn length(&mut self) -> f64 {
         match self.length {
-            None      => { let mut len: f64 = 0f64; 
+            None      => { let mut len: f64 = 0.0; 
                            for i in &self.values {
                                len.inc_by(i.square());
                            }
@@ -62,6 +66,7 @@ impl MathVector {
     ///
     /// # Returns
     /// A `&Vec<f64>`.
+    #[must_use]
     pub fn get_values(&self) -> &Vec<f64> {
         &self.values
     }
@@ -79,6 +84,22 @@ impl MathVector {
             false => { core::panic!("{}", INV_DIM); } 
         }
     }
+
+    /// Normalises a `MathVector`.
+    ///
+    /// # Examples
+    /// ```
+    /// use lib_rapid::math::vectors::MathVector;
+    /// use lib_rapid::math::vectors::new_mathvec;
+    /// let mut v = new_mathvec!(2,2,2);
+    /// v.normalise(); // Also sets the Length to 1.0.
+    /// assert_eq!(v.length(), 1.0);
+    /// assert_eq!(v.get_values(), &vec!(0.5773502691896258; 3));
+    /// ```
+    pub fn normalise(&mut self) {
+        *self = scalar_mul(1.0 / self.length(), self);
+        self.length = Some(1.0);
+    }
 }
 
 impl std::ops::Add for MathVector {
@@ -122,6 +143,7 @@ impl std::ops::Sub for MathVector {
     ///
     /// # Returns
     /// A new `MathVector`.
+    #[must_use]
 pub fn scalar_mul(scalar: f64, other: &MathVector) -> MathVector {
 
     let mut vals: Vec<f64> = Vec::with_capacity(other.dimension());
@@ -138,6 +160,7 @@ pub fn scalar_mul(scalar: f64, other: &MathVector) -> MathVector {
 /// # Returns
 /// A new `MathVector`.
 #[macro_export]
+#[must_use]
 macro_rules! new_mathvec {
     ( $( $a:expr ),* ) => {
         {
@@ -150,11 +173,12 @@ macro_rules! new_mathvec {
     };
 }
 
+pub use new_mathvec;
+
 impl std::fmt::Display for MathVector {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
         let mut finstring: String = String::from("( ");
         for i in 0..self.dimension() {
-            finstring.push(' ');
             finstring += &self.values[i].to_string();
             finstring.push_str("; ");
         }
